__version__ = "0.6.37"
__git_commiter_name__ = "Guy Rozendorn"
__git_commiter_email__ = "guy@rzn.co.il"
__git_branch__ = '(detached from v0.6.37)'
__git_remote_tracking_branch__ = '(No remote tracking)'
__git_remote_url__ = '(Not remote tracking)'
__git_head_hash__ = 'b98c8a9e935be3efe451d47353dd39aaf464f0e0'
__git_head_subject__ = 'TRIVIAL build_and_upload_distributions: handle empty lines'
__git_head_message__ = ''
__git_dirty_diff__ = ''